//*****************************************************************************
/** @file LV9062USB.h
 **
 ** Definition of the functions exported for the DLL to permit the use of the
 ** Data Acquisition Interface modules (Models 9062-1X, 9062-BX, where X is a
 ** number designating a particular language).
 */
// Copyright Lab-Volt Ltd. All rights reserved 2004
//*****************************************************************************

//
// First function to call in a program.
// Initializes several global variables.
//
void InitVariable();


//	
// Last function to call in a program.
// Used to close Handles required to manage the USB communication.
//
void Exit();


//
// Detects the module connected to the computer.
// Returns 0 if the supply voltage of the module is 120V/60Hz.
// Returns 5 if the supply voltage of the module is 220V/240V 50Hz.
// Returns -1 if there is no module connected to the computer.
//
int  DetectModule();


//
// Sets the time delay (in milliseconds) between connection tests
// with the module.
//
// aTimeOut --> From 0 to 60 000
// DWORD = unsigned long
//
void SetTimeOut(DWORD aTimeOut);


//
// Sets the acquisition frequency, in hertz, according to
// the aFrequency parameter.
//	
// aFrequency --> From 0 to 180 000 
//
void SetFrequency(double aFrequency);


//	
// Returns the approximate value of the current acquisition frequency, in hertz.
//
double GetFrequency();


//
// Sets the status of the relays used to change the gain of the voltage
// inputs (E1,E2 et E3) and current inputs (I1,I2 et I3) according to the aData
// argument. The aData argument is an integer representing 6 bits whose value
// can be 0 (=Low Range) or 1 (=High Range), according to the following
// arrangement:
//		  
//		   I1
//		  I2|
//		 I3||
//	      |||	
//		  XXXXXX
//		     |||
//	       E3||
//		     E2|
//		      E1
//
// aData --> From 0 to 63. In binary, from 0 to 111111.
// aEscFlag --> 0 = Ok; 1 = Escape; 2 = Error 
//
void WriteDigital(int aData, int * aEscFlag);


//
// Returns 6 bits representing the status of the relays used to change the gain
// of the corresponding voltage and current inputs.
// 0 = Low Range, 1 = High Range.
//	
//		   I1
//		  I2|
//		 I3||
//		  |||	
//		  XXXXXX
//		     |||
//		    E3||
//		     E2|
//		      E1
//
// aRange --> From 0 to 63. In binary, from 0 to 111111.
//
void ReadGlobalRangeUSB(int * aRange);


//
// Permits the acquisition of all points (aNbrChannel x aNbrSequence) in the
// channel order stated by list aSequence32. Points are represented by 12-bit
// binary values that are stored in a 32-kilobyte memory on the
// acquisition board.
//
// aNbrChannel = Number of channels through which data acquisition is performed.
// aSequence32 = Pointer of the list of channels.
// aNbrSequence = Number of points to acquire on each channel.
// aEscFlag = Flag indicating whether an error has occurred.
//	
// aNbrChannel --> From 0 to 16
// aSequence32 --> Array whose size corresponds to the number of channels
//				   (maximum of 16 elements) with values comprised between
//				   0 and 15 inclusively according to the following arrangement:
//
//			0	1	2	3	4	5	6	7	8	9	10	11	12	13	14	15
//			E1	E2	E3	I1	I2	I3	T	N	AI1	AI2	AI3	AI4	AI5	AI6	AI7	AI8
//
// aNbrSequence --> From 0 and 8192
// aEscFlag --> 0 = Ok; 1 = Escape; 2 = Error
//
void AcquisitionUSB(int aNbrChannel, int * aSequence32,	int aNbrSequence,
					int * aEscFlag);

	
//
// Permits the transmission, via the USB communication link, of all the
// acquisition points on the form of 64-bit data packets. The points can be
// accessed through array lpBufInfo32. The lists aValMax and aValMin can be
// used to calculate RMS values or to achieve automatic selection of the
// input ranges.
//
// aNbrChannel = Nomber of channels through which data is to be acquired.
// aNbrSequence = Number of points to acquire on each channel.
// apBufInfo32 = Pointer of the buffer containing the points.
// aValMax = List of maximum values for each channel.
// aValMin = List of minimum values for each channel.
// aEscFlag = Flag indicating whether an error has occurred.
// aModule = Module number
//
// aNbrChannel --> From 0 to 16
// aNbrSequence --> From 0 to 8192
// apBufInfo32 --> Array containing a maximum of 8192 elements with values
//				   comprised between 0 and 4095
// aValMax --> Array whose size corresponds to the number of channels
//			   (maximum of 16 elements) with values from 2048 to -2047
// aValMin --> Array whose size corresponds to the number of channels
//			   (maximum of 16 elements) with values from 2048 to -2047
// aEscFlag --> 0 = Ok; 1 = Escape; 2 = Error
// aModule --> 0 = module powered by a voltage of 120V/60Hz (ex: 9062-10)
//			   5 = module powered by a voltage of 220/240V 50Hz (ex: 9062-15)
//
void TransfertUSB(int aNbrChannel, int aNbrSequence, int * apBufInfo32,
				  long * aValMax, long * aValMin, int * aEscFlag,
				  int * aModule);


//	
// Permits the writing of a 12-bit binary value received from argument aData
// into a register associated with analog output 1. This binary value
// is converted into a voltage comprised between -10 and +10 V before it is
// applied across the terminals of analog output 1. Argument aEscFlag permits
// error detection.
//	
// aData --> 4095	+10V
//			 2048	 0V
//				0	-10V
// aEscFlag --> 0 = Ok; 1 = Escape; 2 = Error
//
void WriteAnalog(int aData, int * aEscFlag);

	
//	
// Permits the writing of a 12-bit binary value received from argument aData
// into a register associated with analog output 2. This binary value
// is converted into a voltage comprised between -10 and +10 V before it is
// applied across the terminals of analog output 2. Argument aEscFlag permits 
// error detection.
// 	
// aData --> 4095	+10V
//			 2048	 0V
//				0	-10V
// aEscFlag --> 0 = Ok; 1 = Escape; 2 = Error
//
void WriteAnalog2(int aData, int * aEscFlag);


//
// Used to activate the Sync. Input to permit synchronization with an external
// signal.
// 
// aFlagTrig --> 0 = Internal synchro.; 1 = External synchro. through Sync. Input
//
void TestTrig(int aFlagTrig);

	
//
// Reinitializes the communication between the module and the computer.
// Used after an interruption in USB communication or AC power supply
// to the module.
// Returns TRUE if the reinitialization is successful. 
// Returns FALSE if the reinitialization has failed.
//
BOOL ResetDevice();

	

	
